@@ -1,36 +1,20 @@
-
-
----------------------------------------------------------------------
--- Core types to access the PAGC address standardizer
--- Author: Stephen Woodbridge <woodbri@imaptools.com>
----------------------------------------------------------------------
-
-CREATE TYPE stdaddr AS (
-    building text,
-    house_num text,
-    predir text,
-    qual text,
-    pretype text,
-    name text,
-    suftype text,
-    sufdir text,
-    ruralroute text,
-    extra text,
-    city text,
-    state text,
-    country text,
-    postcode text,
-    box text,
-    unit text
-);
-
-
 ---------------------------------------------------------------------
 -- Core function to access the PAGC address standardizer
 -- Author: Stephen Woodbridge <woodbri@imaptools.com>
 ---------------------------------------------------------------------
 
-CREATE FUNCTION standardize_address(
+-- Availability: 3.4.0
+CREATE OR REPLACE FUNCTION debug_standardize_address(
+        lextab text,
+        gaztab text,
+        rultab text,
+        micro text,
+        macro text DEFAULT NULL )
+    RETURNS text
+    AS  '$libdir/address_standardizer-3', 'debug_standardize_address'
+    LANGUAGE 'c' IMMUTABLE COST 200;
+
+CREATE OR REPLACE FUNCTION standardize_address(
         lextab text,
         gaztab text,
         rultab text,
@@ -40,7 +24,7 @@ CREATE FUNCTION standardize_address(
     AS  '$libdir/address_standardizer-3', 'standardize_address'
     LANGUAGE 'c' IMMUTABLE STRICT COST 200;
 
-CREATE FUNCTION standardize_address(
+CREATE OR REPLACE FUNCTION standardize_address(
         lextab text,
         gaztab text,
         rultab text,
@@ -49,7 +33,7 @@ CREATE FUNCTION standardize_address(
     AS  '$libdir/address_standardizer-3', 'standardize_address1'
     LANGUAGE 'c' IMMUTABLE STRICT COST 200;
 
-CREATE FUNCTION parse_address(IN text,
+CREATE OR REPLACE FUNCTION parse_address(IN text,
         OUT num text,
         OUT street text,
         OUT street2 text,
@@ -63,3 +47,4 @@ CREATE FUNCTION parse_address(IN text,
     AS  '$libdir/address_standardizer-3', 'parse_address'
     LANGUAGE 'c' IMMUTABLE STRICT;
 
+
